@@ -25,10 +25,12 @@ CELLULAR_STATUS = 'cellularStatus'
 CO2 = 'co2'
 PRESSURE = 'pressure'
 MOTION = 'motion'
+DESK_OCCUPANCY = 'deskOccupancy'
 EVENT_TYPES = [
     TOUCH, TEMPERATURE, OBJECT_PRESENT, HUMIDITY, OBJECT_PRESENT_COUNT,
     TOUCH_COUNT, WATER_PRESENT, NETWORK_STATUS, BATTERY_STATUS, LABELS_CHANGED,
     CONNECTION_STATUS, ETHERNET_STATUS, CELLULAR_STATUS, CO2, PRESSURE, MOTION,
+    DESK_OCCUPANCY,
 ]
 
 
@@ -960,14 +962,15 @@ class NetworkStatus(_EventData):
 
     """
 
-    def __init__(
-        self,
-        signal_strength: int,
-        rssi: int,
-        transmission_mode: str,
-        cloud_connectors: list[NetworkStatusCloudConnector],
-        timestamp: Optional[datetime | str] = None
-    ) -> None:
+    def __init__(self,
+                 signal_strength: Optional[int] = None,
+                 rssi: Optional[int] = None,
+                 transmission_mode: Optional[str] = None,
+                 cloud_connectors:
+                 Optional[list[NetworkStatusCloudConnector]] = None,
+                 timestamp: Optional[datetime | str] = None,
+                 ) -> None:
+
         """
         Constructs the NetworkStatus object.
 
@@ -991,10 +994,10 @@ class NetworkStatus(_EventData):
         """
 
         # Set attributes.
-        self.signal_strength: int = signal_strength
-        self.rssi: int = rssi
-        self.transmission_mode: str = transmission_mode
-        self.cloud_connectors: list[NetworkStatusCloudConnector] = \
+        self.signal_strength: Optional[int] = signal_strength
+        self.rssi: Optional[int] = rssi
+        self.transmission_mode: Optional[str] = transmission_mode
+        self.cloud_connectors: Optional[list[NetworkStatusCloudConnector]] = \
             cloud_connectors
         self.timestamp: Optional[datetime | str] = timestamp
 
@@ -1564,7 +1567,7 @@ class Co2(_EventData):
 
     Attributes
     ----------
-    ppm : float
+    ppm : int
         Co2 concentration in parts per million.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
@@ -1572,7 +1575,7 @@ class Co2(_EventData):
     """
 
     def __init__(self,
-                 ppm: float,
+                 ppm: int,
                  timestamp: Optional[datetime | str] = None,
                  ) -> None:
         """
@@ -1580,7 +1583,7 @@ class Co2(_EventData):
 
         Parameters
         ----------
-        ppm : float
+        ppm : int
             Co2 concentration in parts per million.
         timestamp : datetime, str, optional
             Timestamp in either datetime or string iso8601 format
@@ -1589,7 +1592,7 @@ class Co2(_EventData):
         """
 
         # Set parameter attributes.
-        self.ppm: float = ppm
+        self.ppm: int = ppm
         self.timestamp: Optional[datetime | str] = timestamp
 
         # Inherit parent _EventData class init with repacked data dictionary.
@@ -1817,6 +1820,93 @@ class Motion(_EventData):
         return data
 
 
+class DeskOccupancy(_EventData):
+    """
+    Represents the data found in a deskOccupancy event.
+
+    Attributes
+    ----------
+    state : str
+        Indicates whether the sensor predicts "OCCUPIED" or "NOT_OCCUPIED".
+    timestamp : datetime
+        Timestamp of when the event was received by a Cloud Connector.
+
+    """
+
+    def __init__(self,
+                 state: str,
+                 timestamp: Optional[datetime | str] = None,
+                 ) -> None:
+        """
+        Constructs the DeskOccupancy object, inheriting parent class
+        and setting the type-specific attributes.
+
+        Parameters
+        ----------
+        state : str
+            Indicates whether the sensor predicts "OCCUPIED" or "NOT_OCCUPIED".
+        timestamp : datetime, str, optional
+            Timestamp in either datetime or string iso8601 format
+            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+
+        """
+
+        # Set parameter attributes.
+        self.state: str = state
+        self.timestamp: Optional[datetime | str] = timestamp
+
+        # Inherit parent _EventData class init with repacked data dictionary.
+        _EventData.__init__(self, self.__repack(), 'deskOccupancy')
+
+    def __repr__(self) -> str:
+        string = '{}.{}('\
+            'state={}, '\
+            'timestamp={}'\
+            ')'
+        return string.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            repr(self.state),
+            repr(dttrans.to_iso8601(self.timestamp)),
+        )
+
+    @classmethod
+    def _from_raw(cls, data: dict) -> DeskOccupancy:
+        """
+        Constructs a DeskOccupancy object from API response data.
+
+        Parameters
+        ----------
+        data : dict
+            API response data dictionary.
+
+        Returns
+        -------
+        obj : DeskOccupancy
+            Object constructed from the API response data.
+
+        """
+
+        # Construct the object with unpacked parameters.
+        obj = cls(
+            state=data['state'],
+            timestamp=data['updateTime'],
+        )
+
+        # Re-inherit from parent, but now providing response data.
+        _EventData.__init__(obj, data, obj.event_type)
+
+        return obj
+
+    def __repack(self) -> dict:
+        data: dict = dict()
+        if self.state is not None:
+            data['state'] = self.state
+        if self.timestamp is not None:
+            data['updateTime'] = self.timestamp
+        return data
+
+
 class Event(dtoutputs.OutputBase):
     """
     Represents device events.
@@ -1999,7 +2089,13 @@ class __EventsMap():
             attr_name='motion',
             class_name='Motion',
             is_keyed=True,
-        )
+        ),
+        'deskOccupancy': __TypeNames(
+            api_name='deskOccupancy',
+            attr_name='desk_occupancy',
+            class_name='DeskOccupancy',
+            is_keyed=True,
+        ),
     }
 
 
@@ -2009,5 +2105,5 @@ _EventType = Union[
     Touch, Temperature, ObjectPresent, Humidity, ObjectPresentCount,
     TouchCount, WaterPresent, NetworkStatus, NetworkStatusCloudConnector,
     BatteryStatus, LabelsChanged, ConnectionStatus, EthernetStatus,
-    CellularStatus, Co2, Pressure, Motion,
+    CellularStatus, Co2, Pressure, Motion, DeskOccupancy,
 ]
